Edit in Plunker

    <script src="../../../angular.js"></script>
    <div ng-controller="BrokenTable">
      <table>
      <tr>
        <th ng-repeat="heading in headings">{{heading}}</th>
      </tr>
      <tr ng-repeat="filling in fillings">
        <td ng-repeat="fill in filling">{{fill}}</td>
      </tr>
    </table>
    </div>

    var app = angular.module('multi-bootstrap', [])

    .controller('BrokenTable', function($scope) {
        $scope.headings = ['One', 'Two', 'Three'];
        $scope.fillings = [[1, 2, 3], ['A', 'B', 'C'], [7, 8, 9]];
    });

    it('should only insert one table cell for each item in $scope.fillings', function() {
    expect(element.all(by.css('td')).count())
        .toBe(9);
    });

x.html" name="example-example">